==> plantuml-libs-6.4.0.tgz: package/distribution/azure-4/Item/General/ServiceBlobPage.md <==
# ServiceBlobPage


```text
azure-4/Item/General/ServiceBlobPage
```

```text
include('azure-4/Item/General/ServiceBlobPage')
```



| Illustration | ServiceBlobPage | ServiceBlobPageCard | ServiceBlobPageGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/General/ServiceBlobPage.png) | ![illustration for ServiceBlobPage](../../../azure-4/Item/General/ServiceBlobPage.Local.png) | ![illustration for ServiceBlobPageCard](../../../azure-4/Item/General/ServiceBlobPageCard.Local.png) | ![illustration for ServiceBlobPageGroup](../../../azure-4/Item/General/ServiceBlobPageGroup.Local.png) |




## ServiceBlobPage

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBlobPage
include('azure-4/Item/General/ServiceBlobPage')

' renders the element
ServiceBlobPage('ServiceBlobPage', 'Service Blob Page', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBlobPage
include('azure-4/Item/General/ServiceBlobPage')

' renders the element
ServiceBlobPage('ServiceBlobPage', 'Service Blob Page', 'an optional tech label')
@enduml
```

## ServiceBlobPageCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBlobPageCard
include('azure-4/Item/General/ServiceBlobPage')

' renders the element
ServiceBlobPageCard('ServiceBlobPageCard', 'Service Blob Page Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBlobPageCard
include('azure-4/Item/General/ServiceBlobPage')

' renders the element
ServiceBlobPageCard('ServiceBlobPageCard', 'Service Blob Page Card', 'an optional description')
@enduml
```

## ServiceBlobPageGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBlobPageGroup
include('azure-4/Item/General/ServiceBlobPage')

' renders the element
ServiceBlobPageGroup('ServiceBlobPageGroup', 'Service Blob Page Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBlobPageGroup
include('azure-4/Item/General/ServiceBlobPage')

' renders the element
ServiceBlobPageGroup('ServiceBlobPageGroup', 'Service Blob Page Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/azure-4/Item/General/ServiceBlobPage.md <==
# ServiceBlobPage


```text
azure-4/Item/General/ServiceBlobPage
```

```text
include('azure-4/Item/General/ServiceBlobPage')
```



| Illustration | ServiceBlobPage | ServiceBlobPageCard | ServiceBlobPageGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/General/ServiceBlobPage.png) | ![illustration for ServiceBlobPage](../../../azure-4/Item/General/ServiceBlobPage.Local.png) | ![illustration for ServiceBlobPageCard](../../../azure-4/Item/General/ServiceBlobPageCard.Local.png) | ![illustration for ServiceBlobPageGroup](../../../azure-4/Item/General/ServiceBlobPageGroup.Local.png) |




## ServiceBlobPage

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBlobPage
include('azure-4/Item/General/ServiceBlobPage')

' renders the element
ServiceBlobPage('ServiceBlobPage', 'Service Blob Page', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBlobPage
include('azure-4/Item/General/ServiceBlobPage')

' renders the element
ServiceBlobPage('ServiceBlobPage', 'Service Blob Page', 'an optional tech label', 'an optional description')
@enduml
```

## ServiceBlobPageCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBlobPageCard
include('azure-4/Item/General/ServiceBlobPage')

' renders the element
ServiceBlobPageCard('ServiceBlobPageCard', 'Service Blob Page Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBlobPageCard
include('azure-4/Item/General/ServiceBlobPage')

' renders the element
ServiceBlobPageCard('ServiceBlobPageCard', 'Service Blob Page Card', 'an optional description')
@enduml
```

## ServiceBlobPageGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBlobPageGroup
include('azure-4/Item/General/ServiceBlobPage')

' renders the element
ServiceBlobPageGroup('ServiceBlobPageGroup', 'Service Blob Page Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceBlobPageGroup
include('azure-4/Item/General/ServiceBlobPage')

' renders the element
ServiceBlobPageGroup('ServiceBlobPageGroup', 'Service Blob Page Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
